App class

Immutable model representing a store application.

Constructors

App({required String id, required String name, required String category, required String developerName, required double rating, required String imageUrl, required String url, required AppPlatform platform, required bool isFree})
Creates an immutable App instance.
const

Properties

category → String
App category or genre.
final
developerName → String
Developer or publisher name.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique application identifier (package name / App Store ID).
final
imageUrl → String
Primary app icon or artwork URL.
final
isFree → bool
Whether the app is free to install.
final
name → String
Display name of the application.
final
platform → AppPlatform
Platform where the app is published.
final
rating → double
Average user rating.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
Store page URL.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited